@@ -1,5 +1,10 @@
 #!/usr/bin/perl
 
+##############################################################################
+# This script shows you how each graphics primitive and operation works.  It #
+# has not been optimized on purpose, so you can see how each is written.     #
+##############################################################################
+
 use strict;
 
 use Graphics::Framebuffer;
@@ -70,8 +75,8 @@ foreach my $file (@files) {
         {
             'x'            => 1,
             'y'            => 1,
-            'width'        => ($rpi) ? $XX / 3 : $XX * .95,
-            'height'       => ($rpi) ? $YY / 3 : $F->{'H_CLIP'} * .95,
+            'width'        => $XX * .95,
+            'height'       => $F->{'H_CLIP'} * .95,
             'file'         => "$images_path/$file",
             'convertalpha' => ($file =~ /wolf/i) ? 1 : 0,
             'center'       => CENTER_XY,
@@ -94,7 +99,7 @@ foreach my $file (@files) {
 } ## end foreach my $file (@files)
 $SIG{'QUIT'} = sub { $F->clip_reset(); $F->cls('ON'); exec('reset'); };
 $SIG{'INT'}  = sub { $F->clip_reset(); $F->cls('ON'); exec('reset'); };
-$F->wait_for_console(1);
+$F->wait_for_console(!$rpi);
 $F->cls('OFF');
 $F->splash($VERSION);
 sleep 1;
@@ -945,7 +950,17 @@ sub polygons {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        $F->polygon({ 'coordinates' => [rand($XX), int(rand($YY)), int(rand($XX)), int(rand($YY)), int(rand($XX)), int(rand($YY)), int(rand($XX)), int(rand($YY))], 'antialiased' => $aa });
+        my $points = int(rand(2)) + 3;
+        my $coords = [];
+        foreach my $p (1 .. $points) {
+            push(@{$coords}, int(rand($XX)), int(rand($YY)));
+        }
+        $F->polygon(
+            {
+                'coordinates' => $coords,
+                'antialiased' => $aa
+            }
+        );
     }
 } ## end sub polygons
 
@@ -956,7 +971,7 @@ sub filled_polygons {
     my $s = time + $factor;
     while (time < $s) {
         $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        my $points = int(rand(10)) + 3;
+        my $points = int(rand(2)) + 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -978,7 +993,7 @@ sub hatch_filled_polygons {
     while (time < $s) {
         $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
         $F->set_b_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        my $points = int(rand(10)) + 3;
+        my $points = int(rand(2)) + 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -1004,7 +1019,7 @@ sub vertical_gradient_polygons {
         my @red    = map { $_ = int(rand(256)) } (1 .. $count);
         my @green  = map { $_ = int(rand(256)) } (1 .. $count);
         my @blue   = map { $_ = int(rand(256)) } (1 .. $count);
-        my $points = int(rand(10)) + 3;
+        my $points = int(rand(2)) + 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -1035,7 +1050,7 @@ sub horizontal_gradient_polygons {
         my @red    = map { $_ = int(rand(256)) } (1 .. $count);
         my @green  = map { $_ = int(rand(256)) } (1 .. $count);
         my @blue   = map { $_ = int(rand(256)) } (1 .. $count);
-        my $points = int(rand(10)) + 3;
+        my $points = int(rand(2)) + 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -1064,7 +1079,7 @@ sub texture_filled_polygons {
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 3 : time + $factor * 2;
     while (time < $s) {
         my $image  = $IMAGES[int(rand(scalar(@IMAGES)))];
-        my $points = int(rand(8)) + 3;
+        my $points = int(rand(2)) + 3;
         my $coords = [];
         foreach my $p (1 .. $points) {
             push(@{$coords}, int(rand($XX)), int(rand($YY)));
@@ -1286,7 +1301,6 @@ sub rotate {
 
     foreach my $p (0 .. 1) {
         
-        next if ($F->{'BITS'} == 16);
         my $angle = 0;
 
         my $st = 'Counter-Clockwise Rotate Test ';
@@ -1355,6 +1369,7 @@ sub rotate {
             $angle = 0 if ($angle <= -360);
             $count++;
         } ## end while (time < $s || $count...)
+        last if ($F->{'BITS'} == 16);
     } ## end foreach my $p (0 .. 1)
     $F->acceleration(1);
 } ## end sub rotate
