@@ -11,6 +11,10 @@ use constant {
 
 use List::Util qw(min max);
 
+BEGIN {
+    our $VERSION = 1.00;
+}
+
 sub _perl_logo {
     my $self = shift;
     return unless (exists($self->{'FONTS'}->{'DejaVuSerif'}));
@@ -22,9 +26,9 @@ sub _perl_logo {
     $self->ellipse(
         {
             'x'       => 965 * $hf,
-            'y'       => 70 * $vf,
+            'y'       => 70  * $vf,
             'xradius' => 140 * $hf,
-            'yradius' => 65 * $vf,
+            'yradius' => 65  * $vf,
             'filled'  => TRUE
         }
     );
@@ -32,9 +36,9 @@ sub _perl_logo {
     $self->ellipse(
         {
             'x'       => 960 * $hf,
-            'y'       => 65 * $vf,
+            'y'       => 65  * $vf,
             'xradius' => 140 * $hf,
-            'yradius' => 65 * $vf,
+            'yradius' => 65  * $vf,
             'filled'  => TRUE
         }
     );
@@ -85,7 +89,12 @@ sub splash {
         $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 64 });
         $self->polygon(
             {
-                'coordinates' => [(67.5 * $hf) + $X, (16.875 * $vf) + $Y, (3.325 * $hf) + $X, (178.125 * $vf) + $Y, (267.5 * $hf) + $X, (238.125 * $vf) + $Y, (315 * $hf) + $X, (2.5 * $vf) + $Y],
+                'coordinates' => [
+                    (67.5  * $hf) + $X, (16.875  * $vf) + $Y,
+                    (3.325 * $hf) + $X, (178.125 * $vf) + $Y,
+                    (267.5 * $hf) + $X, (238.125 * $vf) + $Y,
+                    (315   * $hf) + $X, (2.5     * $vf) + $Y
+                ],
                 'filled'      => TRUE,
                 'gradient'    => {
                     'start' => {
@@ -104,9 +113,9 @@ sub splash {
         $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 1 });
         $self->rbox(
             {
-                'x'      => (25 * $hf) + $X,
+                'x'      => (25     * $hf) + $X,
                 'y'      => (28.125 * $vf) + $Y,
-                'width'  => 277.5 * $hf,
+                'width'  => 277.5   * $hf,
                 'height' => 185.625 * $vf,
                 'radius' => 4,
                 'filled' => TRUE
@@ -116,9 +125,9 @@ sub splash {
         $self->set_color({ 'red' => 128, 'green' => 0, 'blue' => 0 });
         $self->rbox(
             {
-                'x'      => (20 * $hf) + $X,
+                'x'      => (20     * $hf) + $X,
                 'y'      => (24.375 * $vf) + $Y,
-                'width'  => 277.5 * $hf,
+                'width'  => 277.5   * $hf,
                 'height' => 185.625 * $vf,
                 'radius' => 4,
                 'filled' => TRUE
@@ -128,8 +137,8 @@ sub splash {
         $self->circle(
             {
                 'x'      => (37.5 * max($vf, $hf)) + $X,
-                'y'      => (36 * max($vf,   $hf)) + $Y,
-                'radius' => 35 * max($vf,    $hf),
+                'y'      => (36   * max($vf, $hf)) + $Y,
+                'radius' => 35    * max($vf, $hf),
                 'filled' => TRUE
             }
         );
@@ -139,7 +148,7 @@ sub splash {
             {
                 'x'        => (35 * max($hf, $vf)) + $X,
                 'y'        => (36 * max($vf, $hf)) + $Y,
-                'radius'   => 35 * max($hf,  $vf),
+                'radius'   => 35  * max($hf, $vf),
                 'filled'   => TRUE,
                 'gradient' => {
                     'direction' => 'horizontal',
@@ -177,8 +186,8 @@ sub splash {
             $self->ttf_print(
                 {
                     'bounding_box' => TRUE,
-                    'x'            => (75 * $hf) + $X,
-                    'y'            => (50 * $vf) + $Y,
+                    'x'            => (75  * $hf) + $X,
+                    'y'            => (50  * $vf) + $Y,
                     'height'       => 37.5 * $vf,
                     'wscale'       => 2,
                     'color'        => $color,
@@ -210,7 +219,7 @@ sub splash {
                 {
                     'bounding_box' => TRUE,
                     'x'            => 0,
-                    'y'            => (50 * $vf) + $Y,
+                    'y'            => (50  * $vf) + $Y,
                     'height'       => 37.5 * $vf,
                     'wscale'       => 2,
                     'color'        => $color,
@@ -242,7 +251,7 @@ sub splash {
                 {
                     'bounding_box' => TRUE,
                     'x'            => (190 * $hf) + $X,
-                    'y'            => (50 * $vf) + $Y,
+                    'y'            => (50  * $vf) + $Y,
                     'height'       => 37.5 * $vf,
                     'wscale'       => 2,
                     'color'        => $color,
@@ -259,7 +268,7 @@ sub splash {
                 'bounding_box' => TRUE,
                 'x'            => 0,
                 'y'            => (100 * $vf) + $Y,
-                'height'       => 42 * $vf,
+                'height'       => 42   * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFF00FF',
                 'text'         => 'Graphics-Framebuffer',
@@ -280,7 +289,7 @@ sub splash {
                     'bounding_box' => TRUE,
                     'x'            => 0,
                     'y'            => (140 * $vf) + $Y,
-                    'height'       => 38 * $vf,
+                    'height'       => 38   * $vf,
                     'wscale'       => 1,
                     'color'        => 'FFFFFFFF',
                     'text'         => sprintf('VERSION %.02f', $version),
@@ -297,7 +306,7 @@ sub splash {
                 'bounding_box' => TRUE,
                 'x'            => 0,
                 'y'            => (190 * $vf) + $Y,
-                'height'       => 48 * $vf,
+                'height'       => 48   * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFFFFFF',
                 'text'         => sprintf('%dx%d-%02d ON %s', $self->{'XRES'}, $self->{'YRES'}, $self->{'BITS'}, uc($self->{'fscreeninfo'}->{'id'} || 'Unknown GPU')),
@@ -320,7 +329,12 @@ sub splash {
         $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 64 });
         $self->polygon(
             {
-                'coordinates' => [(400 * $hf) + $X, (80 * $vf) + $Y, (20 * $hf) + $X, (800 * $vf) + $Y, (1600 * $hf) + $X, (1078 * $vf) + $Y, (1900 * $hf) + $X, (5 * $vf) + $Y],
+                'coordinates' => [
+                    (400  * $hf) + $X, (80   * $vf) + $Y,
+                    (20   * $hf) + $X, (800  * $vf) + $Y,
+                    (1600 * $hf) + $X, (1078 * $vf) + $Y,
+                    (1900 * $hf) + $X, (5    * $vf) + $Y
+                ],
                 'filled'      => TRUE,
                 'gradient'    => {
                     'start' => {
@@ -343,8 +357,8 @@ sub splash {
                 'x'      => (160 * $hf) + $X,
                 'y'      => (160 * $vf) + $Y,
                 'width'  => 1620 * $hf,
-                'height' => 780 * $vf,
-                'radius' => 15 * min($hf, $vf),
+                'height' => 780  * $vf,
+                'radius' => 15   * min($hf, $vf),
                 'filled' => TRUE
             }
         );
@@ -355,8 +369,8 @@ sub splash {
                 'x'      => (150 * $hf) + $X,
                 'y'      => (150 * $vf) + $Y,
                 'width'  => 1620 * $hf,
-                'height' => 780 * $vf,
-                'radius' => 15 * min($hf, $vf),
+                'height' => 780  * $vf,
+                'radius' => 15   * min($hf, $vf),
                 'filled' => TRUE
             }
         );
@@ -367,7 +381,7 @@ sub splash {
             {
                 'x'      => (207 * $hf) + $X,
                 'y'      => (207 * $vf) + $Y,
-                'radius' => 199 * min($vf, $hf),
+                'radius' => 199  * min($vf, $hf),
                 'filled' => TRUE
             }
         );
@@ -377,7 +391,7 @@ sub splash {
             {
                 'x'        => (200 * $hf) + $X,
                 'y'        => (200 * $vf) + $Y,
-                'radius'   => 199 * min($hf, $vf),
+                'radius'   => 199  * min($hf, $vf),
                 'filled'   => TRUE,
                 'gradient' => {
                     'direction' => 'horizontal',
@@ -401,7 +415,7 @@ sub splash {
             {
                 'x'             => (102 * $hf) + $X,
                 'y'             => (202 * $vf) + $Y,
-                'radius'        => 52 * $vf,
+                'radius'        => 52   * $vf,
                 'start_degrees' => 340,
                 'end_degrees'   => 270,
                 'granularity'   => 0.05
@@ -411,7 +425,18 @@ sub splash {
         # F
         $self->polygon(
             {
-                'coordinates' => [(162 * $hf) + $X, (252 * $vf) + $Y, (162 * $hf) + $X, (152 * $vf) + $Y, (262 * $hf) + $X, (152 * $vf) + $Y, (242 * $hf) + $X, (172 * $vf) + $Y, (182 * $hf) + $X, (172 * $vf) + $Y, (182 * $hf) + $X, (192 * $vf) + $Y, (222 * $hf) + $X, (192 * $vf) + $Y, (202 * $hf) + $X, (212 * $vf) + $Y, (182 * $hf) + $X, (212 * $vf) + $Y, (182 * $hf) + $X, (232 * $vf) + $Y],
+                'coordinates' => [
+                    (162 * $hf) + $X, (252 * $vf) + $Y,
+                    (162 * $hf) + $X, (152 * $vf) + $Y,
+                    (262 * $hf) + $X, (152 * $vf) + $Y,
+                    (242 * $hf) + $X, (172 * $vf) + $Y,
+                    (182 * $hf) + $X, (172 * $vf) + $Y,
+                    (182 * $hf) + $X, (192 * $vf) + $Y,
+                    (222 * $hf) + $X, (192 * $vf) + $Y,
+                    (202 * $hf) + $X, (212 * $vf) + $Y,
+                    (182 * $hf) + $X, (212 * $vf) + $Y,
+                    (182 * $hf) + $X, (232 * $vf) + $Y
+                ],
                 'filled'      => TRUE,
                 'pixel_size'  => 1
             }
@@ -420,7 +445,12 @@ sub splash {
         # B
         $self->polygon(
             {
-                'coordinates' => [(272 * $hf) + $X, (252 * $vf) + $Y, (272 * $hf) + $X, (152 * $vf) + $Y, (322 * $hf) + $X, (152 * $vf) + $Y, (322 * $hf) + $X, (252 * $vf) + $Y],
+                'coordinates' => [
+                    (272 * $hf) + $X, (252 * $vf) + $Y,
+                    (272 * $hf) + $X, (152 * $vf) + $Y,
+                    (322 * $hf) + $X, (152 * $vf) + $Y,
+                    (322 * $hf) + $X, (252 * $vf) + $Y
+                ],
                 'filled'      => TRUE,
                 'pixel_size'  => 1
             }
@@ -429,7 +459,7 @@ sub splash {
             {
                 'x'      => (322 * $hf) + $X,
                 'y'      => (177 * $vf) + $Y,
-                'radius' => 25 * $vf,
+                'radius' => 25   * $vf,
                 'filled' => TRUE
             }
         );
@@ -437,7 +467,7 @@ sub splash {
             {
                 'x'      => (322 * $hf) + $X,
                 'y'      => (227 * $vf) + $Y,
-                'radius' => 25 * $vf,
+                'radius' => 25   * $vf,
                 'filled' => TRUE
             }
         );
@@ -461,7 +491,7 @@ sub splash {
             {
                 'x'             => (100 * $hf) + $X,
                 'y'             => (200 * $vf) + $Y,
-                'radius'        => 52 * $vf,
+                'radius'        => 52   * $vf,
                 'start_degrees' => 340,
                 'end_degrees'   => 270,
                 'granularity'   => 0.05
@@ -506,7 +536,12 @@ sub splash {
         }
         $self->polygon(
             {
-                'coordinates' => [(270 * $hf) + $X, (250 * $vf) + $Y, (270 * $hf) + $X, (150 * $vf) + $Y, (320 * $hf) + $X, (150 * $vf) + $Y, (320 * $hf) + $X, (250 * $vf) + $Y],
+                'coordinates' => [
+                    (270 * $hf) + $X, (250 * $vf) + $Y,
+                    (270 * $hf) + $X, (150 * $vf) + $Y,
+                    (320 * $hf) + $X, (150 * $vf) + $Y,
+                    (320 * $hf) + $X, (250 * $vf) + $Y
+                ],
                 'filled'      => TRUE,
                 'pixel_size'  => 1
             }
@@ -515,7 +550,7 @@ sub splash {
             {
                 'x'      => (320 * $hf) + $X,
                 'y'      => (175 * $vf) + $Y,
-                'radius' => 25 * $vf,
+                'radius' => 25   * $vf,
                 'filled' => TRUE
             }
         );
@@ -523,29 +558,29 @@ sub splash {
             {
                 'x'      => (320 * $hf) + $X,
                 'y'      => (225 * $vf) + $Y,
-                'radius' => 25 * $vf,
+                'radius' => 25   * $vf,
                 'filled' => TRUE
             }
         );
         $self->set_color({ 'red' => 32, 'green' => 0, 'blue' => 0 });
         $self->rbox(
             {
-                'x'      => (478 * $hf) + $X,
-                'y'      => (208 * $vf) + $Y,
+                'x'      => (478  * $hf) + $X,
+                'y'      => (208  * $vf) + $Y,
                 'width'  => (1230 * $hf),
-                'height' => (150 * $vf),
+                'height' => (150  * $vf),
+                'radius' => 20    * $vf,
                 'filled' => TRUE,
-                'radius' => 20 * $vf,
             }
         );
         $self->rbox(
             {
-                'x'        => (470 * $hf) + $X,
-                'y'        => (200 * $vf) + $Y,
+                'x'        => (470  * $hf) + $X,
+                'y'        => (200  * $vf) + $Y,
                 'width'    => (1230 * $hf),
-                'height'   => (150 * $vf),
+                'height'   => (150  * $vf),
+                'radius'   => 20    * $vf,
                 'filled'   => TRUE,
-                'radius'   => 20 * $vf,
                 'gradient' => {
                     'start' => {
                         'red'   => 64,
@@ -569,7 +604,7 @@ sub splash {
                         'bounding_box' => TRUE,
                         'x'            => (510 * $hf) + $X,
                         'y'            => (300 * $vf) + $Y,
-                        'height'       => 110 * $vf,
+                        'height'       => 110  * $vf,
                         'wscale'       => 1.5,
                         'color'        => '00FFFFFF',
                         'text'         => 'Imager Assisted',
@@ -586,7 +621,7 @@ sub splash {
                     'bounding_box' => TRUE,
                     'x'            => 0,
                     'y'            => (560 * $vf) + $Y,
-                    'height'       => 200 * $vf,
+                    'height'       => 200  * $vf,
                     'wscale'       => 1,
                     'color'        => '221100FF',
                     'text'         => 'Graphics-Framebuffer',
@@ -610,7 +645,7 @@ sub splash {
                 'bounding_box' => TRUE,
                 'x'            => 0,
                 'y'            => (560 * $vf) + $Y,
-                'height'       => 200 * $vf,
+                'height'       => 200  * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFF00FF',
                 'text'         => 'Graphics-Framebuffer',
@@ -631,7 +666,7 @@ sub splash {
                 'bounding_box' => TRUE,
                 'x'            => 0,
                 'y'            => (620 * $vf) + $Y,
-                'height'       => 50 * $vf,
+                'height'       => 50   * $vf,
                 'wscale'       => 1,
                 'color'        => '00EE00FF',
                 'text'         => 'by Richard Kelsch',
@@ -649,7 +684,7 @@ sub splash {
                     'bounding_box' => TRUE,
                     'x'            => 0,
                     'y'            => (730 * $vf) + $Y,
-                    'height'       => 120 * $vf,
+                    'height'       => 120  * $vf,
                     'wscale'       => 1,
                     'color'        => 'FFFFFFFF',
                     'text'         => sprintf('Version %.02f', $version),
@@ -664,7 +699,7 @@ sub splash {
                 'bounding_box' => TRUE,
                 'x'            => 0,
                 'y'            => (860 * $vf) + $Y,
-                'height'       => 120 * $vf,
+                'height'       => 120  * $vf,
                 'wscale'       => 1,
                 'color'        => 'FFFFFFFF',
                 'text'         => sprintf('%dx%d-%02d on %s', $self->{'XRES'}, $self->{'YRES'}, $self->{'BITS'}, $self->{'fscreeninfo'}->{'id'} || 'Unknown GPU'),
